==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/bg.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Етикети",
    "Update" : "Актуализирай",
    "Create" : "Създай",
    "Select tag…" : "Изберете етикет...",
    "Tagged files" : "Отбелязани файлове",
    "Select tags to filter by" : "Филтриране по етикет",
    "No tags found" : "Няма открити етикети",
    "Please select tags to filter by" : "Филтриране по етикет",
    "No files found for the selected tags" : "Няма намерени файлове за избраните етикети",
    "Added system tag %1$s" : "Добавен системен етикет %1$s",
    "Added system tag {systemtag}" : "Добавен системен етикет {systemtag}",
    "%1$s added system tag %2$s" : "%1$s добави системен етикет %2$s",
    "{actor} added system tag {systemtag}" : "{actor} добави системен етикет {systemtag}",
    "Removed system tag %1$s" : "Премахнат системен етикет %1$s",
    "Removed system tag {systemtag}" : "Премахнат системен етикет {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s премахна системен етикет %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} премахна системен етикет {systemtag}",
    "You created system tag %1$s" : "Създадохте системен етикет %1$s",
    "You created system tag {systemtag}" : "Създадохте системен етикет {systemtag}",
    "%1$s created system tag %2$s" : "%1$s създаде системен етикет %2$s",
    "{actor} created system tag {systemtag}" : "{actor} създаде системен етикет {systemtag}",
    "You deleted system tag %1$s" : "Изтрихте системен етикет %1$s",
    "You deleted system tag {systemtag}" : "Изтрихте системен етикет {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s изтри системен етикет %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} изтри системен етикет {systemtag}",
    "You updated system tag %2$s to %1$s" : "Актуализирахте системен етикет %2$s на %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Актуализирахте системен етикет {oldsystemtag} на {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s акутализиран системен етикет %3$s на %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} Актуализира системен етикет {oldsystemtag} на {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Добавихте системен етикет %2$s на %1$s",
    "You added system tag {systemtag} to {file}" : "Добавихте системен етикет {systemtag} на {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s добави системен етикет %3$s на %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} добави системен етикет {systemtag} на {file}",
    "You removed system tag %2$s from %1$s" : "Премахнахте системен етикет %2$s от %1$s",
    "You removed system tag {systemtag} from {file}" : "Премахнахте системен етикет {systemtag} от {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s премахна системни етикет %3$s от %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} премахна системен етикет {systemtag} от {file}",
    "<strong>System tags</strong> for a file have been modified" : "Промяна на <strong>системни етикети</strong> за файл",
    "Name" : "Име",
    "Public" : "Публичен",
    "Restricted" : "Ограничен",
    "Delete" : "Изтриване",
    "Reset" : "Възстанови",
    "No files in here" : "Тук няма файлове",
    "No entries found in this folder" : "Няма намерени записи в тази папка",
    "Size" : "Размер",
    "Modified" : "Променен на"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/bg.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Етикети",
    "Update" : "Актуализирай",
    "Create" : "Създай",
    "Select tag…" : "Изберете етикет...",
    "Tagged files" : "Отбелязани файлове",
    "Select tags to filter by" : "Филтриране по етикет",
    "No tags found" : "Не са открити етикети",
    "Please select tags to filter by" : "Моля изберете етикети, за филтрирането",
    "No files found for the selected tags" : "Няма намерени файлове за избраните етикети",
    "Added system tag {systemtag}" : "Добавен системен етикет {systemtag}",
    "Added system tag %1$s" : "Добавен системен етикет %1$s",
    "%1$s added system tag %2$s" : "%1$s добави системен етикет %2$s",
    "{actor} added system tag {systemtag}" : "{actor} добави системен етикет {systemtag}",
    "Removed system tag {systemtag}" : "Премахнат системен етикет {systemtag}",
    "Removed system tag %1$s" : "Премахнат системен етикет %1$s",
    "%1$s removed system tag %2$s" : "%1$s премахна системен етикет %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} премахна системен етикет {systemtag}",
    "You created system tag %1$s" : "Създадохте системен етикет %1$s",
    "You created system tag {systemtag}" : "Създадохте системен етикет {systemtag}",
    "%1$s created system tag %2$s" : "%1$s създаде системен етикет %2$s",
    "{actor} created system tag {systemtag}" : "{actor} създаде системен етикет {systemtag}",
    "You deleted system tag %1$s" : "Изтрихте системен етикет %1$s",
    "You deleted system tag {systemtag}" : "Изтрихте системен етикет {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s изтри системен етикет %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} изтри системен етикет {systemtag}",
    "You updated system tag %2$s to %1$s" : "Актуализирахте системен етикет %2$s на %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Актуализирахте системен етикет {oldsystemtag} на {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s акутализиран системен етикет %3$s на %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} Актуализира системен етикет {oldsystemtag} на {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Добавихте системен етикет %2$s на %1$s",
    "You added system tag {systemtag} to {file}" : "Добавихте системен етикет {systemtag} на {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s добави системен етикет %3$s на %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} добави системен етикет {systemtag} на {file}",
    "You removed system tag %2$s from %1$s" : "Премахнахте системен етикет %2$s от %1$s",
    "You removed system tag {systemtag} from {file}" : "Премахнахте системен етикет {systemtag} от {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s премахна системни етикет %3$s от %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} премахна системен етикет {systemtag} от {file}",
    "<strong>System tags</strong> for a file have been modified" : "Промяна на <strong>системни етикети</strong> за файл",
    "Select tag …" : "Изберете етикет...",
    "Create a new tag" : "Създаване на нов етикет",
    "Name" : "Име",
    "Public" : "Публичен",
    "Restricted" : "Ограничен",
    "Invisible" : "Невидим",
    "Delete" : "Изтриване",
    "Reset" : "Нулирай",
    "No files in here" : "Тук няма файлове",
    "No entries found in this folder" : "Няма намерени записи в тази папка",
    "Size" : "Размер",
    "Modified" : "Променен на"
},
"nplurals=2; plural=(n != 1);");
